/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.IOException;

import java.util.HashMap;
import java.util.Map;

import org.json.JSONObject;

/**
 * @author Michael Hashimoto
 */
public class CommitFactory {

	public static Commit newCommit(
		String gitHubUserName, String repositoryName, String sha) {

		String commitURL = _getCommitURL(gitHubUserName, repositoryName, sha);

		if (_commits.containsKey(commitURL)) {
			return _commits.get(commitURL);
		}

		try {
			JSONObject jsonObject = JenkinsResultsParserUtil.toJSONObject(
				commitURL);

			JSONObject commitJSONObject = jsonObject.getJSONObject("commit");

			String message = commitJSONObject.getString("message");

			return newCommit(gitHubUserName, message, repositoryName, sha);
		}
		catch (IOException ioe) {
			throw new RuntimeException("Unable to get commit details", ioe);
		}
	}

	public static Commit newCommit(
		String gitHubUserName, String message, String repositoryName,
		String sha) {

		String commitURL = _getCommitURL(gitHubUserName, repositoryName, sha);

		if (_commits.containsKey(commitURL)) {
			return _commits.get(commitURL);
		}

		Commit.Type type = Commit.Type.MANUAL;

		if (message.startsWith("archive:ignore")) {
			type = Commit.Type.LEGACY_ARCHIVE;
		}

		Commit commit = new BaseCommit(
			gitHubUserName, message, repositoryName, sha, type);

		_commits.put(commitURL, commit);

		return commit;
	}

	private static String _getCommitURL(
		String gitHubUserName, String repositoryName, String sha) {

		return JenkinsResultsParserUtil.getGitHubApiUrl(
			repositoryName, gitHubUserName, "commits/" + sha);
	}

	private static final Map<String, Commit> _commits = new HashMap<>();

}