/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.File;
import java.io.IOException;

/**
 * @author Michael Hashimoto
 */
public class GitBisectToolJob extends PortalRepositoryJob {

	public GitBisectToolJob(String jobName, String portalBranchName) {
		super(jobName);

		try {
			_jenkinsGitWorkingDirectory =
				JenkinsResultsParserUtil.getJenkinsGitWorkingDirectory();

			_portalGitWorkingDirectory =
				JenkinsResultsParserUtil.getPortalGitWorkingDirectory(
					portalBranchName);
		}
		catch (IOException ioe) {
			throw new RuntimeException(
				"Unable to create a Git working directory", ioe);
		}

		jobProperties.putAll(
			JenkinsResultsParserUtil.getProperties(
				new File(
					_jenkinsGitWorkingDirectory.getWorkingDirectory(),
					"commands/build.properties")));

		jobProperties.putAll(
			JenkinsResultsParserUtil.getProperties(
				new File(
					_jenkinsGitWorkingDirectory.getWorkingDirectory(),
					"commands/dependencies/git-bisect-tool.properties")));
	}

	public GitWorkingDirectory getJenkinsGitWorkingDirectory() {
		return _jenkinsGitWorkingDirectory;
	}

	@Override
	public PortalGitWorkingDirectory getPortalGitWorkingDirectory() {
		return _portalGitWorkingDirectory;
	}

	private final GitWorkingDirectory _jenkinsGitWorkingDirectory;
	private final PortalGitWorkingDirectory _portalGitWorkingDirectory;

}