/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.File;

/**
 * @author Michael Hashimoto
 */
public class JunitPortalBatchBuildRunner extends PortalBatchBuildRunner {

	protected JunitPortalBatchBuildRunner(Job job, String batchName) {
		super(job, batchName);

		_setPortalBuildProperties();
	}

	private void _setPortalBuildProperties() {
		String portalUpstreamBranchName =
			primaryLocalRepository.getUpstreamBranchName();

		if (portalUpstreamBranchName.contains("7.0.x") ||
			portalUpstreamBranchName.contains("7.1.x") ||
			portalUpstreamBranchName.contains("master")) {

			String otherPortalBranchName = null;

			if (portalUpstreamBranchName.contains("7.0.x")) {
				otherPortalBranchName = portalUpstreamBranchName.replace(
					"7.0.x", "master");
			}
			else if (portalUpstreamBranchName.contains("7.1.x")) {
				otherPortalBranchName = portalUpstreamBranchName.replace(
					"7.1.x", "7.0.x");
			}
			else {
				otherPortalBranchName = portalUpstreamBranchName.replace(
					"master", "7.0.x");
			}

			String otherPortalRepositoryName = "liferay-portal";

			if (!otherPortalBranchName.equals("master")) {
				otherPortalRepositoryName += "-ee";
			}

			LocalRepository otherPortalLocalRepository =
				RepositoryFactory.getLocalRepository(
					otherPortalRepositoryName, otherPortalBranchName);

			File otherPortalRepositoryDir =
				otherPortalLocalRepository.getDirectory();

			portalBuildProperties.put(
				"release.versions.test.other.dir",
				otherPortalRepositoryDir.toString());
		}
	}

}