/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import java.io.File;

import java.util.Properties;

/**
 * @author Peter Yoo
 */
public class LocalRepository extends BaseRepository {

	public File getDirectory() {
		return directory;
	}

	public GitWorkingDirectory getGitWorkingDirectory() {
		return _gitWorkingDirectory;
	}

	public String getUpstreamBranchName() {
		return _upstreamBranchName;
	}

	public RemoteRepository getUpstreamRemoteRepository() {
		GitWorkingDirectory gitWorkingDirectory = getGitWorkingDirectory();

		return RepositoryFactory.getRemoteRepository(
			gitWorkingDirectory.getRemote("upstream"));
	}

	public void setup() {
		System.out.println("##");
		System.out.println("## " + getDirectory());
		System.out.println("##");

		GitWorkingDirectory gitWorkingDirectory = getGitWorkingDirectory();

		gitWorkingDirectory.reset("--hard HEAD");

		gitWorkingDirectory.clean();
	}

	protected LocalRepository(String name, String upstreamBranchName) {
		super(name);

		_upstreamBranchName = upstreamBranchName;

		Properties repositoryProperties = _getRepositoryProperties();

		String repositoryPropertyKey = getRepositoryPropertyKey();

		if (repositoryProperties.containsKey(repositoryPropertyKey)) {
			directory = new File(
				repositoryProperties.getProperty(repositoryPropertyKey));
		}
		else {
			directory = new File(
				JenkinsResultsParserUtil.getBaseRepositoryDir(),
				getDefaultRelativeRepositoryDirPath());
		}

		if (!directory.exists()) {
			throw new RuntimeException(
				JenkinsResultsParserUtil.combine(
					"Unable to find repository directory for ", getName(),
					" at ", directory.toString()));
		}

		File dotGit = new File(directory, ".git");

		if (!dotGit.exists()) {
			throw new IllegalArgumentException(
				directory + " is not a valid repository");
		}

		_gitWorkingDirectory =
			GitWorkingDirectoryFactory.newGitWorkingDirectory(
				upstreamBranchName, getDirectory(), getName());
	}

	protected String getDefaultRelativeRepositoryDirPath() {
		return getName();
	}

	protected String getRepositoryPropertyKey() {
		return JenkinsResultsParserUtil.combine(
			"repository.dir[", name, "/" + getUpstreamBranchName(), "]");
	}

	protected final File directory;

	private static Properties _getRepositoryProperties() {
		if (_repositoryProperties != null) {
			return _repositoryProperties;
		}

		File repositoryPropertiesFile = new File("repository.properties");

		_repositoryProperties = JenkinsResultsParserUtil.getProperties(
			repositoryPropertiesFile);

		return _repositoryProperties;
	}

	private static Properties _repositoryProperties;

	private final GitWorkingDirectory _gitWorkingDirectory;
	private final String _upstreamBranchName;

}