/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import com.liferay.jenkins.results.parser.GitWorkingDirectory.Remote;

/**
 * @author Peter Yoo
 */
public class RepositoryFactory {

	public static LocalRepository getLocalRepository(
		String repositoryName, String upstreamBranchName) {

		if (repositoryName.startsWith("com-liferay-")) {
			return new SubrepositoryLocalRepository(
				repositoryName, upstreamBranchName);
		}

		if (repositoryName.startsWith("liferay-plugins")) {
			return new PluginsLocalRepository(
				repositoryName, upstreamBranchName);
		}

		if (repositoryName.startsWith("liferay-portal")) {
			return new PortalLocalRepository(
				repositoryName, upstreamBranchName);
		}

		return new LocalRepository(repositoryName, upstreamBranchName);
	}

	public static RemoteRepository getRemoteRepository(Remote remote) {
		String hostname = remote.getHostname();

		if (hostname.equalsIgnoreCase("github.com")) {
			return new GitHubRemoteRepository(remote);
		}

		return new RemoteRepository(remote);
	}

	public static RemoteRepository getRemoteRepository(
		String hostname, String repositoryName, String username) {

		if (hostname.equalsIgnoreCase("github.com")) {
			return new GitHubRemoteRepository(repositoryName, username);
		}

		return new RemoteRepository(hostname, repositoryName, username);
	}

}